﻿using System;
using System.Collections.Generic;
using System.Xml;
using System.IO;

/// <summary>
/// Summary description for AdminPanelSettings
/// </summary>
public class AdminPanelSettings
{
    public struct PluginStruct
    {
        public string Caption;
        public string FolderName;
    }

    #region Fields
    
    protected AdminPanelSettings _instance;

    public List<PluginStruct> _Plugins;
    protected string _User;
    protected string _Pass;
    protected string _Host;
    protected string _Port;
    protected string _LicenseKey;
    protected bool _AdvancedOptions;

    #endregion

    #region Properties

    public List<PluginStruct> Plugins
    {
        get { return _Plugins; }
        set { _Plugins = value; }
    }

    public string User
    {
        get { return _User; }
        set { _User = value; }
    }

    public string Pass
    {
        get { return _Pass; }
        set { _Pass = value; }
    }

    public string Host
    {
        get { return _Host; }
        set { _Host = value; }
    }

    public string Port
    {
        get { return _Port; }
        set { _Port = value; }
    }

    public string LicenseKey
    {
        get { return _LicenseKey; }
        set { _LicenseKey = value; }
    }

    public bool AdvancedOptions
    {
        get { return _AdvancedOptions; }
        set { _AdvancedOptions = value; }
    }

    #endregion

    public AdminPanelSettings()
    {
        _Plugins = new List<PluginStruct>();
        _User = string.Empty;
        _Pass = string.Empty;
        _Host = string.Empty;
        _Port = string.Empty;
        _LicenseKey = string.Empty;
        _AdvancedOptions = false;
    }

    public AdminPanelSettings CreateInstance()
    {
        if (_instance == null)
        {
            _instance = new AdminPanelSettings();
            _instance.LoadAdminPanelSettings();
        }

        return _instance;
    }

    public void _LoadXML(XmlNode root)
    {
        for (int i = 0; i < root.ChildNodes.Count; i++)
        {
            XmlNode node = root.ChildNodes[i];
            switch (node.Name)
            {
                case "plugins":
                case "login":
                    if (node.ChildNodes.Count > 0)
                        _LoadXML(node);
                    break;
                case "plugin":
                    PluginStruct ps = new PluginStruct();
                    ps.Caption = node.Attributes["caption"].Value;
                    ps.FolderName = node.Attributes["folderName"].Value;
                    Plugins.Add(ps);
                    break;
                case "user":
                    User = node.InnerText;
                    break;
                case "password":
                    Pass = node.InnerText;
                    break;
                case "host":
                    Host = node.InnerText;
                    break;
                case "port":
                    Port = node.InnerText;
                    break;
                case "licensekey":
                    LicenseKey = node.InnerText;
                    break;
                case "advancedoptions":
                    AdvancedOptions = (node.InnerText == "1") ? true : false;
                    break;
            }
        }
    }

    
    public void LoadAdminPanelSettings()
    {
        LoadAdminPanelSettings(Utils.GetAdminPanelDataFolderPath());
    }

    public void LoadAdminPanelSettings(string dataFolder)
    {
        string filename = Path.Combine(dataFolder, @"adminpanel.xml");
        XmlDocument doc = new XmlDocument();
        doc.Load(filename);
        XmlNode root = doc.DocumentElement;
        _LoadXML(root);
    }

    public void SaveAdminPanelSettings()
    {
        SaveAdminPanelSettings(Utils.GetAdminPanelDataFolderPath());
    }

    public void SaveAdminPanelSettings(string dataFolder)
    {
        try
        {
            string filename = Path.Combine(dataFolder, @"adminpanel.xml");

            XmlDocument result = new XmlDocument();
            result.PreserveWhitespace = false;
            XmlDeclaration xmlDecl = result.CreateXmlDeclaration("1.0", "utf-8", "");
            result.AppendChild(xmlDecl);

            XmlElement settingsElem = result.CreateElement("settings");
            result.AppendChild(settingsElem);

            XmlElement subElemPlugins = result.CreateElement("plugins");
            settingsElem.AppendChild(subElemPlugins);

            XmlElement subElemLogin = result.CreateElement("login");
            settingsElem.AppendChild(subElemLogin);

            XmlElement subElem = result.CreateElement("user");
            subElem.AppendChild(result.CreateTextNode(User));
            subElemLogin.AppendChild(subElem);

            subElem = result.CreateElement("password");
            subElem.AppendChild(result.CreateTextNode(Pass));
            subElemLogin.AppendChild(subElem);

            subElem = result.CreateElement("host");
            subElem.AppendChild(result.CreateTextNode(Host));
            subElemLogin.AppendChild(subElem);
            
            subElem = result.CreateElement("port");
            subElem.AppendChild(result.CreateTextNode(Port));
            subElemLogin.AppendChild(subElem);

            foreach (PluginStruct ps in Plugins)
            {
                subElem = result.CreateElement("plugin");
                subElem.SetAttribute("caption", ps.Caption);
                subElem.SetAttribute("folderName", ps.FolderName);
                subElemPlugins.AppendChild(subElem);
            }

            XmlElement subElemLicenseKey = result.CreateElement("licensekey");
            subElemLicenseKey.AppendChild(result.CreateTextNode(LicenseKey));
            settingsElem.AppendChild(subElemLicenseKey);

            XmlElement subElemAdvancedOptions = result.CreateElement("advancedoptions");
            subElemAdvancedOptions.AppendChild(result.CreateTextNode(AdvancedOptions ? "1" : "0"));
            settingsElem.AppendChild(subElemAdvancedOptions);

            result.Save(filename);
            _instance = null;
        }
        catch (Exception){ }
    }


}
