using System;
using MailBee.Mime;

namespace WebMailLite
{
	public class CheckMailEventArgs : EventArgs
	{
		protected string _folderName = "";
		protected int _msgsCount = 0;
		protected int _msgNumber = 0;

		public string FolderName
		{
			get { return _folderName; }
		}

		public int MsgsCount
		{
			get { return _msgsCount; }
		}

		public int MsgsNumber
		{
			get { return _msgNumber; }
		}

		public CheckMailEventArgs(string folderName, int msgsCount, int msgsNumber)
		{
			_folderName = folderName;
			_msgsCount = msgsCount;
			_msgNumber = msgsNumber;
		}
	}

	public class DeleteMessageEventArgs : EventArgs
	{
		protected int _msgIndex = 0;
		protected string _folderName = string.Empty;

		public int MessageIndex
		{
			get { return _msgIndex; }
		}

		public string FolderName
		{
			get { return _folderName; }
		}

		public DeleteMessageEventArgs(int index, string folderName)
		{
			_msgIndex = index;
			_folderName = folderName;
		}
	}

	public delegate void DownloadedMessageHandler(object sender, CheckMailEventArgs e);

	public delegate void DeleteMessageHanlder(object sender, DeleteMessageEventArgs e);

	// Mail Storage: POP3, IMAP, any DB
	public abstract class MailStorage
	{
		public event DownloadedMessageHandler MessageDownloaded;
		public event DeleteMessageHanlder MessageDeleted;

		protected string _folderName = "";
		protected int _msgsCount = 0;
		protected int _msgNumber = 0;

		protected Account _account = null;

		public Account Account
		{
			get { return _account; }
			set { _account = value; }
		}

		protected virtual void OnMessageDownloaded(CheckMailEventArgs e) 
		{
			if (MessageDownloaded != null)
				MessageDownloaded(this, e);
		}

		protected virtual void OnMessageDeleted(DeleteMessageEventArgs e)
		{
			if (MessageDeleted != null)
				MessageDeleted(this, e);
		}

		public MailStorage(Account account) { _account = account; }

		public virtual void Connect(bool login) {}

		public virtual bool IsConnected() { return false; }

		public virtual void Disconnect() {}

		public virtual long GetMailStorageSize() { return 0; }

		public virtual int GetMessageCount() { return 0; }

		public virtual MailMessageCollection LoadMessageHeaders(int pageNumber) { return null; }

		public virtual MailMessage LoadMessage(string uid) { return null; }

		public virtual void DeleteMessages(string[] messageUidSet) {}

	}// END CLASS DEFINITION MailStorage

	public abstract class MailServerStorage	: MailStorage
	{
		public MailServerStorage(Account account) : base(account) {}

		public abstract int GetInboxMessageCount(string fullPath);

		public abstract int GetInboxUnreadMessageCount(string fullPath);
	}// END CLASS DEFINITION MailServerStorage

	public class MailServerStorageCreator
	{
		public static MailServerStorage CreateMailServerStorage(Account acct)
		{
            switch (acct.MailProtocol)
            {
                case IncomingMailProtocol.WMServer:
                    return new WMServerStorage(acct);
                case IncomingMailProtocol.Pop3:
                    return new Pop3Storage(acct);
                default:
                    return null;
            }
			
		}
	}
}
